@@ -1,4 +1,4 @@
-import {escapeText} from "../../../common"
+import {escapeText, localizeDate} from "../../../common"
 
 /** A template for HTML export of a book. */
 export const htmlBookExportTemplate = ({styleSheets, part, currentPart, contents, title}) =>
@@ -7,7 +7,7 @@ export const htmlBookExportTemplate = ({styleSheets, part, currentPart, contents
     <head>
         <meta charset="UTF-8">
         <title>${title}</title>
-        <link type="text/css" rel="stylesheet" href="css/document.css" />
+        <link type="text/css" rel="stylesheet" href="css/book.css" />
         ${
     styleSheets.map(sheet =>
         `<link type="text/css" rel="stylesheet" href="${sheet.filename}" />`
@@ -53,17 +53,31 @@ const htmlBookIndexItemTemplate = ({item, multiDoc}) =>
 
 /** A template to create the book index. */
 export const htmlBookIndexBodyTemplate = ({book, contentItems, language, creator, multiDoc}) =>
-    `<h1>${escapeText(book.title)}</h1>
+    `<div class="titlepage frontmatter">
+        <h1 class="booktitle">${escapeText(book.title)}</h1>
         ${
     book.metadata.subtitle.length ?
-        `<h2>${escapeText(book.metadata.subtitle)}</h2>` :
+        `<h2 class="booksubtitle">${escapeText(book.metadata.subtitle)}</h2>` :
         ''
 }
         ${
     book.metadata.author.length ?
-        `<h3>${gettext('by')} ${escapeText(book.metadata.author)}</h3>` :
+        `<h3 class="bookauthor">${gettext('by')} ${escapeText(book.metadata.author)}</h3>` :
         ''
 }
+    </div>
+    <div class="copyrightpage frontmatter">
+        ${
+    book.metadata.publisher && book.metadata.publisher.length ?
+        `<p>${gettext('Published by')}: ${escapeText(book.metadata.publisher)}</p>` :
+        ''
+}
+        <p>${gettext('Last Updated')}: ${localizeDate(book.updated * 1000, 'sortable-date')}</p>
+        <p>${gettext('Created')}: ${localizeDate(book.added * 1000, 'sortable-date')}</p>
+        <p>${gettext('Language')}: ${language}</p>
+        <p>${gettext('Created by')}: ${escapeText(creator)}</p>
+    </div>
+    <div class="tocpage frontmatter">
         <nav role="doc-toc"><ol>
             ${
     contentItems.map(item =>
@@ -71,15 +85,7 @@ export const htmlBookIndexBodyTemplate = ({book, contentItems, language, creator
     ).join('')
 }
         </ol></nav>
-        ${
-    book.metadata.publisher && book.metadata.publisher.length ?
-        `<p>${gettext('Published by')}: ${escapeText(book.metadata.publisher)}</p>` :
-        ''
-}
-        <p>${gettext('Last Updated')}: ${book.updated}</p>
-        <p>${gettext('Created')}: ${book.added}</p>
-        <p>${gettext('Language')}: ${language}</p>
-        <p>${gettext('Created by')}: ${escapeText(creator)}</p>`
+    </div>`
 
 /** A template to create the book index. */
 export const htmlBookIndexTemplate = ({book, contentItems, language, creator, styleSheets, multiDoc}) =>
@@ -88,7 +94,7 @@ export const htmlBookIndexTemplate = ({book, contentItems, language, creator, st
     <head>
         <meta charset="utf-8"></meta>
         <title>${escapeText(book.title)}</title>
-        <link type="text/css" rel="stylesheet" href="css/document.css" />
+        <link type="text/css" rel="stylesheet" href="css/book.css" />
         ${
     styleSheets.map(sheet =>
         `<link type="text/css" rel="stylesheet" href="${sheet.filename}" />`
@@ -96,6 +102,33 @@ export const htmlBookIndexTemplate = ({book, contentItems, language, creator, st
 }
     </head>
     <body class="book-index">
-        ${htmlBookIndexBodyTemplate({book, contentItems, language, creator, styleSheets, multiDoc})}
+        ${htmlBookIndexBodyTemplate({book, contentItems, language, creator, multiDoc})}
+    </body>
+</html>`
+
+
+export const singleFileHTMLBookChapterTemplate = ({part, contents}) => `
+    ${
+    part && part.length ?
+        `<h1 class="part">${escapeText(part)}</h1>` :
+        ''
+}
+    ${contents}`
+
+export const singleFileHTMLBookTemplate = ({css, html, title, styleSheets}) => `<!DOCTYPE html>
+<html>
+    <head>
+        <meta charset="UTF-8">
+        <title>${title}</title>
+        <link type="text/css" rel="stylesheet" href="css/book.css" />
+        <style>
+            ${css}
+        </style>
+        ${styleSheets.map(sheet =>
+        sheet.filename ? `<link type="text/css" rel="stylesheet" href="${sheet.filename}" />` : ''
+    ).join('')}
+    </head>
+    <body class="user-contents">
+        ${html}
     </body>
 </html>`
